timeintervaltools.explode_intervals_into_n_trees_heuristically
==============================================================

.. autofunction:: abjad.tools.timeintervaltools.explode_intervals_into_n_trees_heuristically.explode_intervals_into_n_trees_heuristically
